@@ -21,7 +21,7 @@ from .sqlparse import SQLFormatWithPrefix
 from .apiparse import APIRequestStringFormatWithPrefix
 
 from .commands.load import loadPlugin
-from .commands.load import loadDriver
+from .commands.load import loadJDBCDriver
 from .commands.load import loadMap
 from .commands.exit import exitApplication
 from .commands.session import sessionManage
@@ -38,12 +38,15 @@ from .commands.cliSleep import cliSleep
 from .commands.userNameSpace import userNameSpace
 from .commands.whenever import setWheneverAction
 from .commands.ssh import executeSshRequest
-from .commands.job import executeJobRequest
+from .commands.ssh import rewriteSshRequest
+from .commands.compare import executeCompareRequest
 
+from .common import rewriteHintStatement
 from .common import rewriteSQLStatement
 from .common import rewriteAPIStatement
 from .common import parseSQLHints
 from .common import parseAPIHints
+from .common import sortresult
 from .testcliexception import TestCliException
 from .globalvar import lastCommandResult
 
@@ -72,10 +75,8 @@ class CmdExecute(object):
         self.mappingHandler = None
 
         # Scenario名称，如果当前未指定，则重复上一个命令的Scenario信息
-        self.scenario = ''
-
-        # Transaction信息
-        self.transaction = ""
+        self.scenarioId = ''
+        self.scenarioName = ''
 
         # 当前脚本的TimeOut设置
         self.sqlTimeOut = -1          # SQL执行的超时时间设置
@@ -156,40 +157,6 @@ class CmdExecute(object):
                 click.secho("[DEBUG] JQ Parse Error: " + repr(je))
             return "****"
 
-    @staticmethod
-    def sortresult(result):
-        # 无法使用系统默认的排序函数，这里空值总是置于最后
-        for i in range(len(result) - 1, 0, -1):
-            for j in range(i - 1, -1, -1):
-                bNeedExchange = False
-                for k in range(0, len(result[i])):
-                    if len(result[i]) != len(result[j]):
-                        return
-                    if result[i][k] is None and result[j][k] is None:
-                        # 两边都是空值
-                        continue
-                    if result[i][k] is None and result[j][k] is not None:
-                        # 左边空值， 右侧不空， 按照左侧大值来考虑
-                        break
-                    if result[j][k] is None and result[i][k] is not None:
-                        # 右侧空值， 左边不空， 按照右侧大值来考虑
-                        bNeedExchange = True
-                        break
-                    if not isinstance(result[i][k], type(result[j][k])):
-                        if str(result[i][k]) < str(result[j][k]):
-                            bNeedExchange = True
-                            break
-                        if str(result[i][k]) > str(result[j][k]):
-                            break
-                    else:
-                        if result[i][k] < result[j][k]:
-                            bNeedExchange = True
-                            break
-                        if result[i][k] > result[j][k]:
-                            break
-                if bNeedExchange:
-                    result[j], result[i] = result[i], result[j]
-
     def getcommandResult(self, cursor, rowcount):
         """
             返回的内容：
@@ -458,6 +425,8 @@ class CmdExecute(object):
         else:
             body = ""
         try:
+            # 重置Header的Content-Length
+            headers["Content-Length"] = len(str(body))
             ret = httpHandler.request(
                 method=httpMethod,
                 url=httpRequestTarget,
@@ -487,7 +456,8 @@ class CmdExecute(object):
                 "status": result
             }
             return
-        except (urllib3.exceptions.MaxRetryError, ) as ex:
+        except (
+                urllib3.exceptions.MaxRetryError, urllib3.exceptions.ProtocolError) as ex:
             yield {
                 "type": "error",
                 "message": str(ex)
@@ -563,9 +533,7 @@ class CmdExecute(object):
                             print("[DEBUG] Apply Sort for this result 2.")
                         # 不能用sorted函数，需要考虑None出现在列表中特定元素的问题
                         # l =  [(-32767,), (32767,), (None,), (0,)]
-                        # l = sorted(l, key=lambda x: (x is None, x))
-                        # '<' not supported between instances of 'NoneType' and 'int'
-                        self.sortresult(result)
+                        sortresult(result)
 
                     # 如果Hint中存在LogFilter，则结果集中过滤指定的输出信息
                     if "LogFilter" in sqlHints.keys() and result is not None:
@@ -715,7 +683,14 @@ class CmdExecute(object):
                         sqlErrorMessage = "\n".join(sqlMultiLineErrorMessage)
                 yield {"type": "error", "message": sqlErrorMessage}
 
-    def runStatement(self, statement: str, commandScriptFile: str, nameSpace: str):
+    def runStatement(self, statement: str,
+                     commandScriptFile: str = "Console",
+                     nameSpace: str = None):
+
+        # 如果没有提供nameSpace，则使用系统默认的nameSpace
+        if nameSpace is None:
+            nameSpace = self.testOptions.get("NAMESPACE")
+
         # Remove spaces and EOL
         statement = statement.strip()
         formattedCommand = None
@@ -727,9 +702,9 @@ class CmdExecute(object):
 
         # DEBUG模式下，打印当前计划要执行的语句
         if "TESTCLI_DEBUG" in os.environ:
-            if self.testOptions.get("NAMESPACE") == "SQL":
+            if nameSpace == "SQL":
                 print("[DEBUG] SQL Command=[" + str(statement) + "]")
-            elif self.testOptions.get("NAMESPACE") == "API":
+            elif nameSpace == "API":
                 print("[DEBUG] API Command=[" + str(statement) + "]")
 
         # 开始解析语句
@@ -737,7 +712,11 @@ class CmdExecute(object):
             ret_CommandSplitResults = []
             ret_CommandSplitResultsWithComments = []
             ret_CommandHints = []
+
+            # 解析前要保留用户的nameSpace，解析后要把这个内容还原
+            # 主要是考虑了执行脚本中，脚本内部含有的nameSpace切换不应该影响到外部的脚本
             defaultNameSpace = self.testOptions.get("NAMESPACE")
+
             # 将所有的语句分拆开，按照行，依次投喂给解析器，以获得被Antlr分拆后的运行结果
             currentStatement = None
             currentStatementWithComments = None
@@ -788,6 +767,7 @@ class CmdExecute(object):
                         # 所有的提示信息
                         ret_CommandHints.append(currentHints)
                         # 清空语句的变量
+                        currentHints = []
                         currentStatement = None
                         currentStatementWithComments = None
                     continue
@@ -814,6 +794,7 @@ class CmdExecute(object):
                                 # 所有的提示信息
                                 ret_CommandHints.append(currentHints)
                                 # 清空语句的变量
+                                currentHints = []
                                 currentStatement = None
                                 currentStatementWithComments = None
                             continue
@@ -829,25 +810,31 @@ class CmdExecute(object):
                             # 所有的提示信息
                             ret_CommandHints.append(currentHints)
                             # 清空语句的变量
+                            currentHints = []
                             currentStatementWithComments = None
 
                     # 没有任何有效的语句，可能是空行或者完全的注释
                     # 对于注释中的Hint信息需要保留下来
-                    pattern = ""
-                    if self.testOptions.get("NAMESPACE") == "SQL":
-                        pattern = r"^(\s+)?--(\s+)?\[(\s+)?Hint(\s+)?\](.*)"
-                    elif self.testOptions.get("NAMESPACE") == "API":
-                        pattern = r"^(\s+)?//(\s+)?\[(\s+)?Hint(\s+)?\](.*)"
+                    # Hint的两种写法
+                    # 1.  -- [Hint]  hintsomething
+                    # 2.  -- [hitsomething]
+                    pattern = r"^(\s+)?([-/][-/])(\s+)?\[(\s+)?Hint(\s+)?\](.*)"
                     matchObj = re.match(pattern, statementLine, re.IGNORECASE)
                     if matchObj:
-                        currentHints.append(matchObj.group(5).strip())
+                        currentHints.append(matchObj.group(6).strip())
+                    else:
+                        pattern = r"^(\s+)?([-/][-/])(\s+)?\[(.*)\].*"
+                        matchObj = re.match(pattern, statementLine, re.IGNORECASE)
+                        if matchObj:
+                            currentHints.append(matchObj.group(4).strip())
+
                     # 解析后的语句
                     ret_CommandSplitResults.append(None)
                     # 解析前的语句
                     ret_CommandSplitResultsWithComments.append(currentStatementWithComments)
                     # 对于非有效语句，Hint不在当前语句中体现，而是要等到下次有意义的语句进行处理
                     ret_CommandHints.append([])
-                    # 清空语句的变量
+                    # 清空除了Hint以外的其他语句变量
                     currentStatement = None
                     currentStatementWithComments = None
                     continue
@@ -859,9 +846,17 @@ class CmdExecute(object):
                         # 对于SQL的CONNECT命令做特殊处理
                         if ret_CommandSplitResult["name"] == "CONNECT":
                             # 对于数据库连接命令，如果没有给出连接详细信息，并且指定了环境变量，附属环境变量到连接命令后
-                            if "driver" not in ret_CommandSplitResult and "SQLCLI_CONNECTION_URL" in os.environ:
-                                (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-                                    = SQLAnalyze(currentStatement + "@" + os.environ["SQLCLI_CONNECTION_URL"])
+                            if "driver" not in ret_CommandSplitResult:
+                                connectionURL = None
+                                if "SQLCLI_CONNECTION_URL" in os.environ:
+                                    connectionURL = \
+                                        str(os.environ["SQLCLI_CONNECTION_URL"]).strip('"').strip("'").strip()
+                                elif "TESTCLI_CONNECTION_URL" in os.environ:
+                                    connectionURL = \
+                                        str(os.environ["TESTCLI_CONNECTION_URL"]).strip('"').strip("'").strip()
+                                if connectionURL is not None:
+                                    (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+                                        = SQLAnalyze(currentStatement + "@" + connectionURL)
                     # 语句已经结束, 记录语句解析的结果
                     # 解析后的语句
                     ret_CommandSplitResults.append(ret_CommandSplitResult)
@@ -870,6 +865,7 @@ class CmdExecute(object):
                     # 所有的提示信息
                     ret_CommandHints.append(currentHints)
                     # 清空语句的变量
+                    currentHints = []
                     currentStatement = None
                     currentStatementWithComments = None
                     continue
@@ -890,6 +886,18 @@ class CmdExecute(object):
 
             # 记录命令开始时间
             startTime = time.time()
+            try:
+                self.sqlTimeOut = int(self.testOptions.get("SQL_TIMEOUT"))
+            except ValueError:
+                self.sqlTimeOut = -1
+            try:
+                self.apiTimeOut = int(self.testOptions.get("API_TIMEOUT"))
+            except ValueError:
+                self.apiTimeOut = -1
+            try:
+                self.scriptTimeOut = int(self.testOptions.get("SCRIPT_TIMEOUT"))
+            except ValueError:
+                self.scriptTimeOut = -1
 
             # 首先打印原有语句
             if self.testOptions.get("NAMESPACE") == "SQL":
@@ -900,13 +908,16 @@ class CmdExecute(object):
             # 如果是空语句，不需要执行，但可能是完全注释行
             # 也可能是一个解析错误的语句
             if ret_CommandSplitResults[pos] is None:
-                yield {
-                    "type": "parse",
-                    "rawCommand": ret_CommandSplitResults[pos],
-                    "formattedCommand": formattedCommand,
-                    "rewrotedCommand": [],
-                    "script": commandScriptFile
-                }
+                if self.loopMode and not self.loopCondition:
+                    pass
+                else:
+                    yield {
+                        "type": "parse",
+                        "rawCommand": ret_CommandSplitResults[pos],
+                        "formattedCommand": formattedCommand,
+                        "rewrotedCommand": [],
+                        "script": commandScriptFile
+                    }
                 pos = pos + 1
                 continue
             else:
@@ -918,16 +929,14 @@ class CmdExecute(object):
                     pos = pos + 1
                     continue
 
-            # 返回SQL的解析信息
-            if commandScriptFile != "Console":
-                # 如果是控制台显示，不再回显原命令，没有任何实际意义
-                yield {
-                    "type": "parse",
-                    "rawCommand": ret_CommandSplitResults[pos],
-                    "formattedCommand": formattedCommand,
-                    "rewrotedCommand": [],
-                    "script": commandScriptFile
-                }
+            # 返回Command的解析信息
+            yield {
+                "type": "parse",
+                "rawCommand": ret_CommandSplitResults[pos],
+                "formattedCommand": formattedCommand,
+                "rewrotedCommand": [],
+                "script": commandScriptFile
+            }
 
             # 处理超时时间问题
             if self.scriptTimeOut > 0:
@@ -975,6 +984,42 @@ class CmdExecute(object):
                 self.timeOutMode = None
                 self.timeout = -1
 
+            # 处理Hints信息
+            if self.testOptions.get("NAMESPACE") == "SQL":
+                commandHintList = parseSQLHints(list(ret_CommandHints[pos]))
+            elif self.testOptions.get("NAMESPACE") == "API":
+                commandHintList = parseAPIHints(list(ret_CommandHints[pos]))
+            else:
+                commandHintList = {}
+            for commandHintKey, commandHintValue in commandHintList.items():
+                # 根据语句中的变量或者其他定义信息来重写当前语句
+                if type(commandHintValue) == str:
+                    # 只针对字符串进行处理，暂时不对其他数据类型进行处理
+                    commandHintNewValue, rewrotedCommandHintValueList = rewriteHintStatement(
+                        cls=self.cliHandler,
+                        statement=commandHintValue,
+                        commandScriptFile=commandScriptFile
+                    )
+                    if len(rewrotedCommandHintValueList) != 0:
+                        commandHintList[commandHintKey] = commandHintNewValue
+                        yield {
+                            "type": "parse",
+                            "rawCommand": None,
+                            "formattedCommand": None,
+                            "rewrotedCommand":
+                                ["REWROTED Hint> " + str(commandHintKey) + ":" + str(commandHintNewValue), ],
+                            "script": commandScriptFile
+                        }
+            if "ScenarioName" in commandHintList:
+                scenarioName = str(commandHintList["ScenarioName"])
+                scenarioId = str(commandHintList["ScenarioId"])
+                if scenarioName.strip().upper() == 'END':
+                    self.scenarioName = ""
+                    self.scenarioId = ""
+                else:
+                    self.scenarioName = scenarioName
+                    self.scenarioId = scenarioId
+
             # 处理各种命令
             sqlKeyWords = ["SELECT", "DELETE", "UPDATE", "CREATE", "INSERT",
                            "DROP", "COMMIT", "ROLLBACK",
@@ -989,6 +1034,9 @@ class CmdExecute(object):
                 ):
                     yield commandResult
             elif parseObject["name"] == "START":
+                # 执行脚本前记录当前执行的脚本名称
+                savedExecuteScript = self.cliHandler.executeScript
+                self.cliHandler.executeScript = parseObject["script"]
                 # 执行脚本文件
                 for commandResult in executeFile(
                         cls=self.cliHandler,
@@ -996,6 +1044,8 @@ class CmdExecute(object):
                         argv=parseObject["argv"],
                 ):
                     yield commandResult
+                # 执行脚本后还原当前执行脚本的名称
+                self.cliHandler.executeScript = savedExecuteScript
             elif parseObject["name"] in ["EXIT", "QUIT"]:
                 # 执行脚本文件
                 if "exitValue" in parseObject.keys():
@@ -1006,6 +1056,13 @@ class CmdExecute(object):
                         cls=self.cliHandler,
                         exitValue=exitValue
                 ):
+                    if commandResult["type"] == "result":
+                        lastCommandResult.clear()
+                        lastCommandResult["status"] = commandResult["status"]
+                        lastCommandResult["errorCode"] = 0
+                    if commandResult["type"] == "error":
+                        lastCommandResult["status"] = commandResult["message"]
+                        lastCommandResult["errorCode"] = 1
                     yield commandResult
             elif parseObject["name"] == "CONNECT":
                 # 执行CONNECT命令
@@ -1014,11 +1071,20 @@ class CmdExecute(object):
                             cls=self.cliHandler,
                             connectProperties=parseObject
                     ):
+                        if commandResult["type"] == "result":
+                            lastCommandResult.clear()
+                            lastCommandResult["status"] = commandResult["status"]
+                            lastCommandResult["errorCode"] = 0
+                        if commandResult["type"] == "error":
+                            lastCommandResult["message"] = commandResult["message"]
+                            lastCommandResult["errorCode"] = 1
                         yield commandResult
                 else:
+                    lastCommandResult["message"] = "Not support connect command in non-sql namespace"
+                    lastCommandResult["errorCode"] = 1
                     yield {
                         "type": "error",
-                        "message": "affadsfsad",
+                        "message": "Not support connect command in non-sql namespace",
                         "script": commandScriptFile
                     }
             elif parseObject["name"] == "SET":
@@ -1027,6 +1093,13 @@ class CmdExecute(object):
                         cls=self.cliHandler,
                         options=parseObject
                 ):
+                    if commandResult["type"] == "result":
+                        lastCommandResult.clear()
+                        lastCommandResult["status"] = commandResult["status"]
+                        lastCommandResult["errorCode"] = 0
+                    if commandResult["type"] == "error":
+                        lastCommandResult["status"] = commandResult["message"]
+                        lastCommandResult["errorCode"] = 1
                     yield commandResult
             elif parseObject["name"] == "DISCONNECT":
                 # 执行DISCONNECT命令
@@ -1034,6 +1107,13 @@ class CmdExecute(object):
                     for commandResult in disconnectDb(
                             cls=self.cliHandler
                     ):
+                        if commandResult["type"] == "result":
+                            lastCommandResult.clear()
+                            lastCommandResult["status"] = commandResult["status"]
+                            lastCommandResult["errorCode"] = 0
+                        if commandResult["type"] == "error":
+                            lastCommandResult["status"] = commandResult["message"]
+                            lastCommandResult["errorCode"] = 1
                         yield commandResult
                 else:
                     yield {
@@ -1062,9 +1142,6 @@ class CmdExecute(object):
                         "script": commandScriptFile
                     }
 
-                # 处理Hints信息
-                commandHintList = parseSQLHints(list(ret_CommandHints[pos]))
-
                 # 执行SQL语句
                 for result in self.executeSQLStatement(
                         sql=sqlCommand,
@@ -1073,12 +1150,12 @@ class CmdExecute(object):
                     if result["type"] == "result":
                         lastCommandResult["rows"] = result["rows"]
                         lastCommandResult["headers"] = result["headers"]
-                        lastCommandResult["message"] = result["status"]
+                        lastCommandResult["status"] = result["status"]
                         lastCommandResult["errorCode"] = 0
                     if result["type"] == "error":
                         lastCommandResult["rows"] = []
                         lastCommandResult["headers"] = []
-                        lastCommandResult["message"] = result["message"]
+                        lastCommandResult["status"] = result["message"]
                         lastCommandResult["errorCode"] = 1
                     yield result
             elif parseObject["name"] in ["USE"]:
@@ -1086,18 +1163,39 @@ class CmdExecute(object):
                         cls=self.cliHandler,
                         nameSpace=parseObject["nameSpace"]
                 ):
+                    if commandResult["type"] == "result":
+                        lastCommandResult.clear()
+                        lastCommandResult["status"] = commandResult["status"]
+                        lastCommandResult["errorCode"] = 0
+                    if commandResult["type"] == "error":
+                        lastCommandResult["status"] = commandResult["message"]
+                        lastCommandResult["errorCode"] = 1
                     yield commandResult
             elif parseObject["name"] in ["SLEEP"]:
                 for commandResult in cliSleep(
                         cls=self.cliHandler,
                         sleepTime=parseObject["sleepTime"]
                 ):
+                    if commandResult["type"] == "result":
+                        lastCommandResult.clear()
+                        lastCommandResult["status"] = commandResult["status"]
+                        lastCommandResult["errorCode"] = 0
+                    if commandResult["type"] == "error":
+                        lastCommandResult["status"] = commandResult["message"]
+                        lastCommandResult["errorCode"] = 1
                     yield commandResult
             elif parseObject["name"] in ["SPOOL"]:
                 for commandResult in spool(
                         cls=self.cliHandler,
                         fileName=parseObject["file"]
                 ):
+                    if commandResult["type"] == "result":
+                        lastCommandResult.clear()
+                        lastCommandResult["status"] = commandResult["status"]
+                        lastCommandResult["errorCode"] = 0
+                    if commandResult["type"] == "error":
+                        lastCommandResult["status"] = commandResult["message"]
+                        lastCommandResult["errorCode"] = 1
                     yield commandResult
             elif parseObject["name"] in ["SESSION"]:
                 for commandResult in sessionManage(
@@ -1105,37 +1203,99 @@ class CmdExecute(object):
                         action=parseObject["action"],
                         sessionName=parseObject["sessionName"]
                 ):
+                    if commandResult["type"] == "result":
+                        lastCommandResult.clear()
+                        lastCommandResult["status"] = commandResult["status"]
+                        lastCommandResult["errorCode"] = 0
+                    if commandResult["type"] == "error":
+                        lastCommandResult["status"] = commandResult["message"]
+                        lastCommandResult["errorCode"] = 1
                     yield commandResult
             elif parseObject["name"] in ["SCRIPT"]:
                 for commandResult in executeEmbeddScript(
                         cls=self.cliHandler,
                         block=parseObject["block"]
                 ):
+                    if commandResult["type"] == "result":
+                        lastCommandResult.clear()
+                        lastCommandResult["status"] = commandResult["status"]
+                        lastCommandResult["errorCode"] = 0
+                    if commandResult["type"] == "error":
+                        lastCommandResult["status"] = commandResult["message"]
+                        lastCommandResult["errorCode"] = 1
                     yield commandResult
             elif parseObject["name"] in ["ASSERT"]:
                 for commandResult in assertExpression(
                         cls=self.cliHandler,
-                        expression=parseObject["expression"]
+                        expression=parseObject["expression"],
+                        assertName=parseObject["assertName"]
                 ):
+                    if commandResult["type"] == "result":
+                        lastCommandResult.clear()
+                        lastCommandResult["status"] = commandResult["status"]
+                        lastCommandResult["errorCode"] = 0
+                    if commandResult["type"] == "error":
+                        lastCommandResult["status"] = commandResult["message"]
+                        lastCommandResult["errorCode"] = 1
                     yield commandResult
             elif parseObject["name"] in ["LOAD"]:
                 if parseObject["option"] == "PLUGIN":
                     for commandResult in loadPlugin(
+                            cls=self.cliHandler,
                             pluginFile=parseObject["pluginFile"]
                     ):
+                        if commandResult["type"] == "result":
+                            lastCommandResult.clear()
+                            lastCommandResult["status"] = commandResult["status"]
+                            lastCommandResult["errorCode"] = 0
+                        if commandResult["type"] == "error":
+                            lastCommandResult["status"] = commandResult["message"]
+                            lastCommandResult["errorCode"] = 1
                         yield commandResult
-                elif parseObject["option"] == "DRIVER":
-                    for commandResult in loadDriver(
+                elif parseObject["option"] == "JDBCDRIVER":
+                    driverName = None
+                    driverClass = None
+                    driverFile = None
+                    driverURL = None
+                    driverProps = None
+                    if "driverName" in parseObject:
+                        driverName = parseObject["driverName"]
+                    if "driverClass" in parseObject:
+                        driverClass = parseObject["driverClass"]
+                    if "driverFile" in parseObject:
+                        driverFile = parseObject["driverFile"]
+                    if "driverURL" in parseObject:
+                        driverURL = parseObject["driverURL"]
+                    if "driverProps" in parseObject:
+                        driverProps = parseObject["driverProps"]
+                    for commandResult in loadJDBCDriver(
                             cls=self.cliHandler,
-                            driverName=parseObject["driverName"],
-                            driverFile=parseObject["driverFile"]
+                            driverName=driverName,
+                            driverClass=driverClass,
+                            driverFile=driverFile,
+                            driverURL=driverURL,
+                            driverProps=driverProps
                     ):
+                        if commandResult["type"] == "result":
+                            lastCommandResult.clear()
+                            lastCommandResult["status"] = commandResult["status"]
+                            lastCommandResult["errorCode"] = 0
+                        if commandResult["type"] == "error":
+                            lastCommandResult["status"] = commandResult["message"]
+                            lastCommandResult["errorCode"] = 1
                         yield commandResult
                 elif parseObject["option"] == "MAP":
                     for commandResult in loadMap(
                             cls=self.cliHandler,
                             mapFile=parseObject["mapFile"]
                     ):
+                        if commandResult["type"] == "result":
+                            lastCommandResult.clear()
+                            lastCommandResult["status"] = commandResult["status"]
+                            lastCommandResult["errorCode"] = 0
+                        if commandResult["type"] == "error":
+                            lastCommandResult["status"] = commandResult["message"]
+                            lastCommandResult["errorCode"] = 1
                         yield commandResult
             elif parseObject["name"] in ["HTTP"]:
                 if self.ifMode and not self.ifCondition:
@@ -1157,9 +1317,6 @@ class CmdExecute(object):
                         "script": commandScriptFile
                     }
 
-                # 处理Hints信息
-                commandHintList = parseAPIHints(list(ret_CommandHints[pos]))
-
                 # 执行HTTP请求
                 for result in self.executeAPIStatement(
                         apiRequest=parseObject,
@@ -1168,7 +1325,7 @@ class CmdExecute(object):
                     if result["type"] == "result":
                         lastCommandResult.clear()
                         data = json.loads(result["status"])
-                        lastCommandResult["data"] = data["content"]
+                        lastCommandResult["content"] = data["content"]
                         lastCommandResult["status"] = data["status"]
                         lastCommandResult["errorCode"] = 0
                     if result["type"] == "error":
@@ -1229,14 +1386,33 @@ class CmdExecute(object):
                 ):
                     yield result
             elif parseObject["name"] in ["SSH"]:
+                parseObject, rewrotedCommandList = rewriteSshRequest(
+                    cls=self.cliHandler,
+                    requestObject=parseObject,
+                    commandScriptFile=commandScriptFile
+                )
+                if len(rewrotedCommandList) != 0:
+                    # 如果命令被发生了改写，要打印改写记录
+                    yield {
+                        "type": "parse",
+                        "rawCommand": None,
+                        "formattedCommand": None,
+                        "rewrotedCommand": rewrotedCommandList,
+                        "script": commandScriptFile
+                    }
+
                 for result in executeSshRequest(
+                        requestObject=parseObject,
+                ):
+                    yield result
+            elif parseObject["name"] in ["JOB"]:
+                for result in self.cliHandler.JobHandler.processRequest(
                         cls=self.cliHandler,
                         requestObject=parseObject,
                 ):
                     yield result
-            elif parseObject["name"] in ["SSH"]:
-                for result in executeJobRequest(
-                        cls=self.cliHandler,
+            elif parseObject["name"] in ["COMPARE"]:
+                for result in executeCompareRequest(
                         requestObject=parseObject,
                 ):
                     yield result
@@ -1250,11 +1426,32 @@ class CmdExecute(object):
             endTime = time.time()
             lastCommandResult["elapsed"] = endTime - startTime
 
-            # 记录SQL日志信息
+            # 记录命令的日志信息
             if self.testOptions.get("SILENT").upper() == 'OFF':
+                if parseObject["name"] == "START":
+                    commandStatus = ""
+                    commandErrorCode = ""
+                else:
+                    if "status" in lastCommandResult:
+                        commandStatus = lastCommandResult["status"]
+                    else:
+                        commandStatus = ""
+                    if "errorCode" in lastCommandResult:
+                        commandErrorCode = lastCommandResult["errorCode"]
+                    else:
+                        commandErrorCode = ""
                 yield {
                     "type": "statistics",
+                    "startedTime": startTime,
                     "elapsed": endTime - startTime,
+                    "thread_name": self.workerName,
+                    "rawCommand": ret_CommandSplitResultsWithComments[pos],
+                    "commandType": parseObject["name"],
+                    "command": json.dumps(obj=parseObject, sort_keys=True, ensure_ascii=False),
+                    "commandStatus": commandStatus,
+                    "errorCode": commandErrorCode,
+                    "scenarioId": self.scenarioId,
+                    "scenarioName": self.scenarioName
                 }
 
             # 开始执行下一个语句
