@@ -725,7 +725,7 @@ class SQLVisitor(SQLParserVisitor):
         if len(ctx.COMPARE_NOTRIM()) != 0:
             compareOptions.update({"trim": False})
         output = []
-        if len(ctx.COMPARE_CONSOLE()) !=0:
+        if len(ctx.COMPARE_CONSOLE()) != 0:
             output.append("console")
         if len(ctx.COMPARE_DIFFFILE()) != 0:
             output.append("diffFile")
@@ -793,6 +793,48 @@ class SQLVisitor(SQLParserVisitor):
         self.errorCode = errorCode
         self.errorMsg = errorMsg
 
+    def visitData(self, ctx: SQLParser.DataContext):
+        parsedObject = {'name': 'DATA'}
+
+        if ctx.DATA_SET() is not None:
+            parsedObject.update({"action": "set"})
+            if ctx.DATA_SEEDFILE() is not None:
+                parsedObject.update({"option": "seedDir"})
+                if len(ctx.DATA_EXPRESSION()) != 0:
+                    parsedObject.update({"seedDir": str(ctx.DATA_EXPRESSION()[0].getText()).strip()})
+
+        if ctx.DATA_CONVERT() is not None:
+            parsedObject.update({"action": "convert"})
+            parsedObject.update({"sourceFileType": str(ctx.DATA_FILETYPE()[0].getText())})
+            parsedObject.update({"targetFileType": str(ctx.DATA_FILETYPE()[1].getText())})
+            parsedObject.update({"sourceFile": str(ctx.DATA_EXPRESSION()[0].getText())})
+            parsedObject.update({"targetFile": str(ctx.DATA_EXPRESSION()[1].getText())})
+
+        if ctx.DATA_CREATE() is not None:
+            parsedObject.update({"action": "create"})
+            parsedObject.update({"fileType": str(ctx.DATA_FILETYPE()[0].getText())})
+            parsedObject.update({"targetFile": str(ctx.DATA_EXPRESSION()[0].getText())})
+            if ctx.DATA_ROWS() is not None:
+                parsedObject.update({"rowCount": int(ctx.DATA_INT().getText())})
+            columnExpression = ""
+            for column in ctx.DATACOLUMN_EXPRESSION():
+                columnExpression = columnExpression + str(column.getText())
+            if ctx.DATA_ROWS() is not None:
+                columnExpression = columnExpression.replace("\n", "")
+            parsedObject.update({"columnExpression": str(columnExpression)})
+
+        # 处理错误信息
+        errorCode = 0
+        errorMsg = None
+        if ctx.exception is not None:
+            errorCode = 1
+            errorMsg = ctx.exception.message
+            self.isFinished = False
+
+        self.parsedObject = parsedObject
+        self.errorCode = errorCode
+        self.errorMsg = errorMsg
+
     def visitStart(self, ctx: SQLParser.StartContext):
         parsedObject = {'name': 'START'}
 
@@ -896,17 +938,10 @@ class SQLVisitor(SQLParserVisitor):
         parsedObject = {'name': 'HOST'}
 
         # 删除BLOCK 末尾的 ECHO OFF
-        if ctx.HOST_BLOCK() is not None:
-            script = str(ctx.HOST_BLOCK().getText())
-            if script.endswith('"""'):
-                script = script[3:-3].strip()
-                script = " & ".join(script.split('\n'))
-                parsedObject.update({'script': script})
-            else:
-                self.isFinished = False
-        else:
-            self.isFinished = False
-            parsedObject.update({'script': ""})
+        if ctx.HOST_EXPRESSION() is not None:
+            script = str(ctx.HOST_EXPRESSION().getText()).strip().strip('"').strip("'").strip("\n")
+            script = script.replace("\n", " & ")
+            parsedObject.update({'script': script})
 
         # 获取错误代码
         errorCode = 0
@@ -923,46 +958,56 @@ class SQLVisitor(SQLParserVisitor):
         parsedObject = {'name': 'LOAD'}
 
         # 加载的选项
-        option = str(ctx.LOAD_OPTION().getText()).strip().upper()
-        parsedObject.update({"option": option})
-
-        # 加载的内容
-        if ctx.LOAD_EXPRESSION() is not None:
-            if option.upper() == "DRIVER":
-                driverName = None
-                driverFile = None
-                if len(ctx.LOAD_EXPRESSION()) >= 1:
-                    driverName = str((ctx.LOAD_EXPRESSION()[0].getText())).strip()
-                    if driverName.startswith('"') and driverName.endswith('"'):
-                        driverName = driverName[1:-1]
-                    if driverName.startswith("'") and driverName.endswith("'"):
-                        driverName = driverName[1:-1]
-                if len(ctx.LOAD_EXPRESSION()) >= 2:
-                    driverFile = str((ctx.LOAD_EXPRESSION()[1].getText())).strip()
-                    if driverFile.startswith('"') and driverFile.endswith('"'):
-                        driverFile = driverFile[1:-1]
-                    if driverFile.startswith("'") and driverFile.endswith("'"):
-                        driverFile = driverFile[1:-1]
-                parsedObject.update(
-                    {
-                        "driverName": driverName,
-                        "driverFile": driverFile,
-                     }
-                )
-            if option.upper() == "PLUGIN":
-                pluginFile = str((ctx.LOAD_EXPRESSION()[0].getText())).strip()
-                if pluginFile.startswith('"') and pluginFile.endswith('"'):
-                    pluginFile = pluginFile[1:-1]
-                if pluginFile.startswith("'") and pluginFile.endswith("'"):
-                    pluginFile = pluginFile[1:-1]
-                parsedObject.update({"pluginFile": pluginFile})
-            if option.upper() == "MAP":
-                mapFile = str((ctx.LOAD_EXPRESSION()[0].getText())).strip()
-                if mapFile.startswith('"') and mapFile.endswith('"'):
-                    mapFile = mapFile[1:-1]
-                if mapFile.startswith("'") and mapFile.endswith("'"):
-                    mapFile = mapFile[1:-1]
-                parsedObject.update({"mapFile": mapFile})
+        if ctx.LOAD_PLUGIN() is not None:
+            parsedObject.update({"option": "PLUGIN"})
+            pluginFile = str((ctx.LOAD_EXPRESSION()[0].getText())).strip()
+            pluginFile = pluginFile.strip('"').strip("'")
+            parsedObject.update({"pluginFile": pluginFile})
+        if ctx.LOAD_MAP() is not None:
+            parsedObject.update({"option": "MAP"})
+            mapFile = str((ctx.LOAD_EXPRESSION()[0].getText())).strip()
+            mapFile = mapFile.strip('"').strip("'")
+            parsedObject.update({"mapFile": mapFile})
+        if ctx.LOAD_JDBCDRIVER() is not None:
+            parsedObject.update({"option": "JDBCDRIVER"})
+        if len(ctx.LOAD_JDBCCLASS()) != 0:
+            optionCtx = ctx.LOAD_JDBCCLASS()[0]
+            start, _ = optionCtx.getSourceInterval()
+            for token in ctx.parser._input.tokens[start+1:]:
+                if str(token.text) != '=':
+                    parsedObject.update({"driverClass": str(token.text)})
+                    break
+        if len(ctx.LOAD_JDBCURL()) != 0:
+            optionCtx = ctx.LOAD_JDBCURL()[0]
+            start, _ = optionCtx.getSourceInterval()
+            for token in ctx.parser._input.tokens[start+1:]:
+                if str(token.text) != '=':
+                    jdbcurl = str(token.text).strip('"').strip("'")
+                    parsedObject.update({"driverURL": str(jdbcurl)})
+                    break
+        if len(ctx.LOAD_JDBCFILE()) != 0:
+            optionCtx = ctx.LOAD_JDBCFILE()[0]
+            start, _ = optionCtx.getSourceInterval()
+            for token in ctx.parser._input.tokens[start+1:]:
+                if str(token.text) != '=':
+                    driverFile = str(token.text).strip('"').strip("'")
+                    parsedObject.update({"driverFile": driverFile})
+                    break
+        if len(ctx.LOAD_JDBCNAME()) != 0:
+            optionCtx = ctx.LOAD_JDBCNAME()[0]
+            start, _ = optionCtx.getSourceInterval()
+            for token in ctx.parser._input.tokens[start+1:]:
+                if str(token.text) != '=':
+                    parsedObject.update({"driverName": str(token.text)})
+                    break
+        if len(ctx.LOAD_JDBCPROP()) != 0:
+            optionCtx = ctx.LOAD_JDBCPROP()[0]
+            start, _ = optionCtx.getSourceInterval()
+            for token in ctx.parser._input.tokens[start+1:]:
+                if str(token.text) != '=':
+                    driverProps = str(token.text).strip('"').strip("'")
+                    parsedObject.update({"driverProps": driverProps})
+                    break
 
         # 获取错误代码
         errorCode = 0
@@ -1063,15 +1108,34 @@ class SQLVisitor(SQLParserVisitor):
             block = ctx.ScriptBlock().getText()
             if str(block).endswith('%}'):
                 block = str(block[:-2])
-                if str(block).endswith('{%'):
-                    block = str(block[2:])
-                block = block.strip()
+                # 去掉第一个空行以及末尾不必要的空格
+                block = block.lstrip('\n')
+                block = block.rstrip()
+
+                # 如果脚本仅有一行，则前导空格没有意义，直接去掉
+                if len(block.split('\n')) == 1:
+                    block = block.strip()
+
+                # 替换所有的前导4字节空格（如果存在）
+                block = block.replace('\t', '    ')
+                minHeaderSpace = 99999
+                for line in block.split('\n'):
+                    if len(line) == 0:
+                        continue
+                    if minHeaderSpace > len(line) - len(line.lstrip()):
+                        minHeaderSpace = len(line) - len(line.lstrip())
+                # 如果脚本整体推进了4个空格，则认为没有推进（推进会让代码美观）
+                if minHeaderSpace == 4:
+                    newLines = []
+                    for line in block.split('\n'):
+                        newLines.append(line[4:])
+                    block = "\n".join(newLines)
                 parsedObject.update({'block': block})
+
             else:
                 self.isFinished = False
         else:
             self.isFinished = False
-
         # 获取错误代码
         errorCode = 0
         errorMsg = None
@@ -1096,6 +1160,11 @@ class SQLVisitor(SQLParserVisitor):
         else:
             parsedObject.update({'expression': ""})
 
+        if ctx.ASSERT_NAME() is not None:
+            parsedObject.update({'assertName': str(ctx.ASSERT_NAME().getText()).strip()})
+        else:
+            parsedObject.update({'assertName': None})
+
         # 获取错误代码
         errorCode = 0
         errorMsg = None
