@@ -5,13 +5,14 @@ import unittest
 import os
 import jpype
 import tempfile
-from testcli.sqlparse import SQLAnalyze
-from testcli.apiparse import APIAnalyze
-from testcli.compare import POSIXCompare
-from testcli.sqlclijdbc import connect as jdbcconnect
-from testcli.test.testmockserver import startServer
-from testcli.test.testmockserver import stopServer
-from testcli.test.testmockserver import waitServerRunning
+from ..sqlparse import SQLAnalyze
+from ..apiparse import APIAnalyze
+from ..commands.compare import POSIXCompare
+from ..sqlclijdbc import connect as jdbcconnect
+from ..test.testmockserver import startServer
+from ..test.testmockserver import stopServer
+from ..test.testmockserver import waitServerRunning
+from ..testcli import TestCli
 
 
 class TestSynatx(unittest.TestCase):
@@ -32,7 +33,8 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_ConnectLocalMem(self):
+    def test_SQLAnalyze_ConnectH2Mem(self):
+        # connect with local h2 mem
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_connect /mem")
         self.assertTrue(isFinished)
@@ -40,7 +42,7 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_ConnectLocalMeta(self):
+        # Connect with testcli metadata
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_connect /metadata")
         self.assertTrue(isFinished)
@@ -48,7 +50,7 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_ConnectWithoutServer(self):
+        # connect without server url
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_connect admin/123456")
         self.assertTrue(isFinished)
@@ -59,7 +61,7 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_ConnectOracle8(self):
+        # Connect with Oracle8
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_connect \"工具人1号\"/123456@jdbc:oracle:thin://192.168.1.72:1521:xe")
         self.assertTrue(isFinished)
@@ -76,7 +78,7 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_ConnectOracle11(self):
+        # Connect with Oracle11
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_connect system/123456@jdbc:oracle:thin://192.168.1.72:1521/xe")
         self.assertTrue(isFinished)
@@ -92,7 +94,8 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_ConnectTeradata(self):
+        # connect with teradata
+        # teradata与众不同，其没有serviceName的存在
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_connect testdblink/testdblink@jdbc:teradata://192.168.1.136/testbase")
         self.assertTrue(isFinished)
@@ -106,7 +109,7 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_ConnectH2Mem(self):
+        # Connect with named h2 session
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_connect sa/sa@jdbc:h2tcp:tcp://127.0.0.1:19091/mem:test")
         self.assertTrue(isFinished)
@@ -122,6 +125,38 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
+        # Connect with IPV6
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_connect sa/sa@jdbc:h2tcp:tcp://[0:0:0:0:0:ffff:192.1.56.10]:19091/mem:test")
+        self.assertTrue(isFinished)
+        self.assertEqual({'driver': 'jdbc',
+                          'driverSchema': 'h2tcp',
+                          'driverType': 'tcp',
+                          'host': '[0:0:0:0:0:ffff:192.1.56.10]',
+                          'name': 'CONNECT',
+                          'password': 'sa',
+                          'port': 19091,
+                          'service': 'mem:test',
+                          'username': 'sa'}, ret_CommandSplitResult)
+        self.assertEqual(0, ret_errorCode)
+        self.assertEqual(None, ret_errorMsg)
+
+        # Connect with IPV6
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_connect sa/sa@jdbc:h2tcp:tcp://[FE80::5689:98FF:FE14]:19091/mem:test")
+        self.assertTrue(isFinished)
+        self.assertEqual({'driver': 'jdbc',
+                          'driverSchema': 'h2tcp',
+                          'driverType': 'tcp',
+                          'host': '[FE80::5689:98FF:FE14]',
+                          'name': 'CONNECT',
+                          'password': 'sa',
+                          'port': 19091,
+                          'service': 'mem:test',
+                          'username': 'sa'}, ret_CommandSplitResult)
+        self.assertEqual(0, ret_errorCode)
+        self.assertEqual(None, ret_errorMsg)
+
     def test_SQLAnalyze_Load(self):
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_load plugin aaa")
@@ -131,14 +166,19 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(None, ret_errorMsg)
 
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
-            = SQLAnalyze("_load driver oracle 'd:\\temp\\aa.txt' ")
+            = SQLAnalyze("_load jdbcdriver name=oracle "
+                         "class=oracle.jdbc.driver.OracleDriver file='d:\\temp\\aa.txt' "
+                         "url='jdbc:oracle:thin:@${host}:${port}/${service}' "
+                         "props='aaa,bbb'")
         self.assertTrue(isFinished)
         self.assertEqual(
-            {
-                'driverName': 'oracle',
-                'driverFile': "d:\\temp\\aa.txt",
-                'name': 'LOAD',
-                'option': 'DRIVER'
+            {'driverClass': 'oracle.jdbc.driver.OracleDriver',
+             'driverFile': 'd:\\temp\\aa.txt',
+             'driverName': 'oracle',
+             'driverProps': 'aaa,bbb',
+             'driverURL': 'jdbc:oracle:thin:@${host}:${port}/${service}',
+             'name': 'LOAD',
+             'option': 'JDBCDRIVER'
              },
             ret_CommandSplitResult)
         self.assertEqual(0, ret_errorCode)
@@ -207,7 +247,7 @@ class TestSynatx(unittest.TestCase):
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_Assert {% assert expresssion %}")
         self.assertTrue(isFinished)
-        self.assertEqual({'name': 'ASSERT', 'expression': ' assert expresssion '}, ret_CommandSplitResult)
+        self.assertEqual({'assertName': None, 'name': 'ASSERT', 'expression': ' assert expresssion '}, ret_CommandSplitResult)
         self.assertEqual(None, ret_errorMsg)
         self.assertEqual(0, ret_errorCode)
 
@@ -326,7 +366,7 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_USEAPI(self):
+    def test_SQLAnalyze_USE(self):
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_use api")
         self.assertTrue(isFinished)
@@ -334,7 +374,6 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_USESQL(self):
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_use sql")
         self.assertTrue(isFinished)
@@ -342,7 +381,6 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(0, ret_errorCode)
         self.assertEqual(None, ret_errorMsg)
 
-    def test_SQLAnalyze_USEXXX(self):
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_use XXX")
         self.assertTrue(isFinished)
@@ -515,6 +553,19 @@ class TestSynatx(unittest.TestCase):
             },
             ret_CommandSplitResult)
 
+        script = 'ls dir1'
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_HOST " + script)
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'name': 'HOST',
+                'script': "ls dir1"
+            },
+            ret_CommandSplitResult)
+
     def test_SQLAnalyze_Loop(self):
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_LOOP END")
@@ -649,6 +700,20 @@ class TestSynatx(unittest.TestCase):
             ret_CommandSplitResult)
 
     def test_SQLAnalyze_Job(self):
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_JOB JOBMANAGER ON")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual({'action': 'startJobmanager', 'name': 'JOB'}, ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_JOB JOBMANAGER OFF")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual({'action': 'stopJobmanager', 'name': 'JOB'}, ret_CommandSplitResult)
+
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_JOB WAIT abcd")
         self.assertEqual(None, ret_errorMsg)
@@ -682,7 +747,7 @@ class TestSynatx(unittest.TestCase):
         self.assertEqual(None, ret_errorMsg)
         self.assertEqual(0, ret_errorCode)
         self.assertTrue(isFinished)
-        self.assertEqual({'action': 'start', 'name': 'JOB', 'timerPoint': 'tp1'}, ret_CommandSplitResult)
+        self.assertEqual({'action': 'timer', 'name': 'JOB', 'timerPoint': 'tp1'}, ret_CommandSplitResult)
 
         (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
             = SQLAnalyze("_JOB START abcd")
@@ -727,6 +792,210 @@ class TestSynatx(unittest.TestCase):
              'name': 'JOB',
              'param': {'Key1': 'Value1', 'Key2': 'Value2'}}, ret_CommandSplitResult)
 
+    def test_SQLAnalyze_Compare(self):
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE aa.txt bb.txt MASK NOCASE")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'compare',
+             'compareOptions': {'case': False, 'mask': True},
+             'name': 'COMPARE',
+             'referenceFile': 'bb.txt',
+             'targetFile': 'aa.txt'}, ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE MASKLINE \"aa bb\"=>\"cc bb\"")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'mask',
+             'compareOptions': {},
+             'name': 'COMPARE',
+             'source': '"aa bb"',
+             'target': '"cc bb"'}, ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE NOMASKLINE \"aa bb\"")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'nomask',
+             'compareOptions': {},
+             'name': 'COMPARE',
+             'source': '"aa bb"'}, ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE SKIPLINE \"aa*bb\"")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'skip',
+             'compareOptions': {},
+             'name': 'COMPARE',
+             'source': '"aa*bb"'}, ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE NOSKIPLINE \"aa*bb\"")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'noskip',
+             'compareOptions': {},
+             'name': 'COMPARE',
+             'source': '"aa*bb"'}, ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE RESET")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'reset',
+             'compareOptions': {},
+             'name': 'COMPARE'}, ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE SET")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'set',
+             'compareOptions': {},
+             'name': 'COMPARE'}, ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE SET MASK CASE IGBLANK NOTRIM")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'set',
+             'compareOptions': {'case': True, 'igblank': True, 'mask': True, 'trim': False},
+             'name': 'COMPARE'}, ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE SET OUTPUT CONSOLE")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'set', 'compareOptions': {'output': ['console']}, 'name': 'COMPARE'},
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE SET OUTPUT DIFFFILE")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'set', 'compareOptions': {'output': ['diffFile']}, 'name': 'COMPARE'},
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE SET OUTPUT CONSOLE DIFFFILE")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'set', 'compareOptions': {'output': ['console', 'diffFile']}, 'name': 'COMPARE'},
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE SET ALGORITHM LCS")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'set', 'compareOptions': {'algorithm': 'lcs'}, 'name': 'COMPARE'},
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE SET ALGORITHM MYERS")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'set', 'compareOptions': {'algorithm': 'myers'}, 'name': 'COMPARE'},
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE SET WORK ENCODING UTF-8")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'set',
+             'compareOptions': {'workEncoding': 'UTF-8'},
+             'name': 'COMPARE'},
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_COMPARE SET REFERENCE ENCODING GBK")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'set', 'compareOptions': {'refEncoding': 'GBK'}, 'name': 'COMPARE'},
+            ret_CommandSplitResult)
+
+    def test_SQLAnalyze_Data(self):
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_DATA SET SEEDFILE DIR d:\\temp\\aa.txt")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {'action': 'set',
+             'name': 'DATA',
+             'option': 'seedDir',
+             'seedDir': 'd:\\temp\\aa.txt'},
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze("_DATA CONVERT FS FILE aa.txt FROM MEM FILE bb.dat")
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'convert',
+                'name': 'DATA',
+                'sourceFile': 'aa.txt',
+                'sourceFileType': 'FS',
+                'targetFile': 'bb.dat',
+                'targetFileType': 'MEM'
+             },
+            ret_CommandSplitResult)
+
+        (isFinished, ret_CommandSplitResult, ret_errorCode, ret_errorMsg) \
+            = SQLAnalyze(
+            "_DATA CREATE FS FILE aa.txt \n" +
+            "[\n" +
+            "random_int(10), 'aaa'\n" +
+            "bb, ccd"
+            + "] rows 1000"
+        )
+        self.assertEqual(None, ret_errorMsg)
+        self.assertEqual(0, ret_errorCode)
+        self.assertTrue(isFinished)
+        self.assertEqual(
+            {
+                'action': 'create',
+                'columnExpression': "random_int(10),'aaa'bb,ccd",
+                'fileType': 'FS',
+                'name': 'DATA',
+                'rowCount': 1000,
+                'targetFile': 'aa.txt'
+             },
+            ret_CommandSplitResult)
+
     def test_SQLExecuteSanity(self):
         scriptFile = "testsqlsanity.sql"
 
@@ -736,11 +1005,9 @@ class TestSynatx(unittest.TestCase):
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
         # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
-        from testcli.testcli import TestCli
         testcli = TestCli(
             logfilename=fullLogFile,
-            HeadlessMode=True,
-            nologo=True,
+            headlessMode=True,
             script=fullScriptFile
         )
         retValue = testcli.run_cli()
@@ -769,11 +1036,9 @@ class TestSynatx(unittest.TestCase):
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
         # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
-        from testcli.testcli import TestCli
         testcli = TestCli(
             logfilename=fullLogFile,
-            HeadlessMode=True,
-            nologo=True,
+            headlessMode=True,
             script=fullScriptFile
         )
         retValue = testcli.run_cli()
@@ -812,11 +1077,9 @@ class TestSynatx(unittest.TestCase):
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
         # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
-        from testcli.testcli import TestCli
         testcli = TestCli(
             logfilename=fullLogFile,
-            HeadlessMode=True,
-            nologo=True,
+            headlessMode=True,
             script=fullScriptFile
         )
         retValue = testcli.run_cli()
@@ -850,11 +1113,9 @@ class TestSynatx(unittest.TestCase):
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
         # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
-        from testcli.testcli import TestCli
         testcli = TestCli(
             logfilename=fullLogFile,
-            HeadlessMode=True,
-            nologo=True,
+            headlessMode=True,
             script=fullScriptFile
         )
         retValue = testcli.run_cli()
@@ -886,11 +1147,9 @@ class TestSynatx(unittest.TestCase):
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
         # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
-        from testcli.testcli import TestCli
         testcli = TestCli(
             logfilename=fullLogFile,
-            HeadlessMode=True,
-            nologo=True,
+            headlessMode=True,
             script=fullScriptFile
         )
         retValue = testcli.run_cli()
@@ -918,11 +1177,9 @@ class TestSynatx(unittest.TestCase):
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
         # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
-        from testcli.testcli import TestCli
         testcli = TestCli(
             logfilename=fullLogFile,
-            HeadlessMode=True,
-            nologo=True,
+            headlessMode=True,
             script=fullScriptFile
         )
         retValue = testcli.run_cli()
@@ -950,11 +1207,9 @@ class TestSynatx(unittest.TestCase):
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
         # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
-        from testcli.testcli import TestCli
         testcli = TestCli(
             logfilename=fullLogFile,
-            HeadlessMode=True,
-            nologo=True,
+            headlessMode=True,
             script=fullScriptFile
         )
         retValue = testcli.run_cli()
@@ -982,11 +1237,9 @@ class TestSynatx(unittest.TestCase):
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
         # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
-        from testcli.testcli import TestCli
         testcli = TestCli(
             logfilename=fullLogFile,
-            HeadlessMode=True,
-            nologo=True,
+            headlessMode=True,
             script=fullScriptFile
         )
         retValue = testcli.run_cli()
@@ -1014,11 +1267,9 @@ class TestSynatx(unittest.TestCase):
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
         # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
-        from testcli.testcli import TestCli
         testcli = TestCli(
             logfilename=fullLogFile,
-            HeadlessMode=True,
-            nologo=True,
+            headlessMode=True,
             script=fullScriptFile
         )
         retValue = testcli.run_cli()
@@ -1037,6 +1288,36 @@ class TestSynatx(unittest.TestCase):
                     print(line)
         self.assertTrue(compareResult)
 
+    def test_SQLJobManager(self):
+        scriptFile = "testjobmanager.sql"
+
+        scriptBaseFile = os.path.splitext(scriptFile)[0]
+        fullScriptFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptFile))
+        fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
+        fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
+
+        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        testcli = TestCli(
+            logfilename=fullLogFile,
+            headlessMode=True,
+            script=fullScriptFile
+        )
+        retValue = testcli.run_cli()
+        self.assertEqual(0, retValue)
+
+        # 对文件进行比对，判断返回结果是否吻合
+        compareHandler = POSIXCompare()
+        compareResult, compareReport = compareHandler.compare_text_files(
+            file1=fullLogFile,
+            file2=fullRefFile,
+            CompareIgnoreTailOrHeadBlank=True
+        )
+        if not compareResult:
+            for line in compareReport:
+                if line.startswith("-") or line.startswith("+"):
+                    print(line)
+        self.assertTrue(compareResult)
+
     def test_APIAnalyze_MultiPart(self):
         scriptFile = "testapisynatx-multipart.api"
 
@@ -1126,11 +1407,9 @@ class TestSynatx(unittest.TestCase):
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
         # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
-        from testcli.testcli import TestCli
         testcli = TestCli(
             logfilename=fullLogFile,
-            HeadlessMode=True,
-            nologo=True,
+            headlessMode=True,
             script=fullScriptFile
         )
         retValue = testcli.run_cli()
@@ -1159,11 +1438,75 @@ class TestSynatx(unittest.TestCase):
         fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
 
         # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
-        from testcli.testcli import TestCli
         testcli = TestCli(
             logfilename=fullLogFile,
-            HeadlessMode=True,
-            nologo=True,
+            headlessMode=True,
+            script=fullScriptFile
+        )
+        retValue = testcli.run_cli()
+        self.assertEqual(0, retValue)
+
+        # 对文件进行比对，判断返回结果是否吻合
+        compareHandler = POSIXCompare()
+
+        compareResult, compareReport = compareHandler.compare_text_files(
+            file1=fullLogFile,
+            file2=fullRefFile,
+            CompareIgnoreTailOrHeadBlank=True
+        )
+        if not compareResult:
+            for line in compareReport:
+                if line.startswith("-") or line.startswith("+"):
+                    print(line)
+        self.assertTrue(compareResult)
+
+    def test_compare(self):
+        scriptFile = "testcompare.sql"
+
+        scriptBaseFile = os.path.splitext(scriptFile)[0]
+        fullScriptFile = os.path.abspath(os.path.join(os.path.dirname(__file__), scriptFile))
+        fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), scriptBaseFile + ".ref"))
+        fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
+
+        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        testcli = TestCli(
+            logfilename=fullLogFile,
+            headlessMode=True,
+            script=fullScriptFile
+        )
+        retValue = testcli.run_cli()
+        self.assertEqual(0, retValue)
+
+        # 对文件进行比对，判断返回结果是否吻合
+        compareHandler = POSIXCompare()
+        compareResult, compareReport = compareHandler.compare_text_files(
+            file1=fullLogFile,
+            file2=fullRefFile,
+            CompareIgnoreTailOrHeadBlank=True
+        )
+        if not compareResult:
+            for line in compareReport:
+                if line.startswith("-") or line.startswith("+"):
+                    print(line)
+        self.assertTrue(compareResult)
+
+        # 删除指定的dif文件
+        fullDiffFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "testcomparework.dif"))
+        self.assertTrue(os.path.exists(fullDiffFile))
+        os.remove(fullDiffFile)
+
+    def test_sqlmapping(self):
+        scriptFile = "testsqlmapping.sql"
+
+        scriptBaseFile = os.path.splitext(scriptFile)[0]
+        fullScriptFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptFile))
+        fullRefFile = os.path.abspath(os.path.join(os.path.dirname(__file__), "", scriptBaseFile + ".ref"))
+        fullLogFile = os.path.abspath(os.path.join(tempfile.gettempdir(), scriptBaseFile + ".log"))
+
+        # 运行测试程序，开启无头模式(不再控制台上显示任何内容),同时不打印Logo
+        testcli = TestCli(
+            logfilename=fullLogFile,
+            headlessMode=True,
             script=fullScriptFile
         )
         retValue = testcli.run_cli()
