@@ -9,30 +9,27 @@ import sqlite3
 import setproctitle
 import click
 import configparser
-import hashlib
 import unicodedata
 import itertools
 import urllib3
-import shutil
 from multiprocessing import Lock
 from time import strftime, localtime
-from urllib.error import URLError
 
 from prompt_toolkit.history import FileHistory
 from prompt_toolkit.shortcuts import PromptSession
 from prompt_toolkit.formatted_text import HTML
 
-from testcli.cmdexecute import CmdExecute
-from testcli.cmdmapping import CmdMapping
-from testcli.hdfswrapper import HDFSWrapper
-from testcli.testcliexception import TestCliException
-from testcli.testclijobmanager import TestCliMeta
-from testcli.testclijobmanager import JOBManager
-from testcli.datawrapper import DataWrapper
-from testcli.testoption import TestOptions
-from testcli.__init__ import __version__
-from testcli.sqlparse import SQLAnalyze
-from testcli.apiparse import APIAnalyze
+from .cmdexecute import CmdExecute
+from .cmdmapping import CmdMapping
+from .hdfswrapper import HDFSWrapper
+from .testcliexception import TestCliException
+from .testclijobmanager import TestCliMeta
+from .testclijobmanager import JOBManager
+from .datawrapper import DataWrapper
+from .testoption import TestOptions
+from .__init__ import __version__
+from .sqlparse import SQLAnalyze
+from .apiparse import APIAnalyze
 
 OFLAG_LOGFILE = 1
 OFLAG_LOGGER = 2
@@ -48,7 +45,6 @@ class TestCli(object):
     # SQLCli的初始化参数
     logon = None
     logfilename = None
-    script = None
     commandMap = None
     nologo = None
 
@@ -67,12 +63,14 @@ class TestCli(object):
             script=None,                            # 脚本文件名，None表示命令行模式
             commandMap=None,                        # SQL映射文件名，None表示不存在
             nologo=False,                           # 是否不打印登陆时的Logo信息，True的时候不打印
+            breakScenarioWithError=False,           # 遇到命令行错误，是否中断当前Scenario继续运行
             breakWithError=False,                   # 遇到命令行错误，是否中断脚本后续执行，立刻退出
             breakErrorCode=255,                     # 遇到命令行错误时候的退出代码
             xlog=None,                              # 扩展日志信息文件输出名，None表示不需要
+            xlogoverwrite=False,                    # 是否覆盖之前的扩展日志
             Console=sys.stdout,                     # 控制台输出，默认为sys.stdout,即标准输出
-            HeadlessMode=False,                     # 是否为无终端模式，无终端模式下，任何屏幕信息都不会被输出
-            WorkerName='MAIN',                      # 程序别名，可用来区分不同的应用程序,
+            headlessMode=False,                     # 是否为无终端模式，无终端模式下，任何屏幕信息都不会被输出
+            workerName='MAIN',                      # 程序别名，可用来区分不同的应用程序,
             logger=None,                            # 程序输出日志句柄
             clientCharset='UTF-8',                  # 客户端字符集，在读取SQL文件时，采纳这个字符集，默认为UTF-8
             resultCharset='UTF-8',                  # 输出字符集，在打印输出文件，日志的时候均采用这个字符集
@@ -103,7 +101,8 @@ class TestCli(object):
         self.xlogFileLocker = None                      # 进程锁, 用来在输出perf文件的时候控制并发写文件
         self.breakWithError = breakWithError            # 是否在遇到错误的时候退出
         self.breakErrorCode = breakErrorCode            # 遇到错误的退出代码
-        
+        self.breakScenarioWithError = breakScenarioWithError  # 遇到命令行错误是否立刻退出当前Scenario的继续运行
+
         # 数据库连接的各种参数
         # 每次连接后需要保存这些变量，下次可以直接重新连接，如果不填写相关信息，则默认上次连接信息
         self.db_conn = None                             # 当前应用的数据库连接句柄
@@ -126,20 +125,26 @@ class TestCli(object):
         if resultCharset is not None:                   # 客户端结果字符集
             self.testOptions.set("RESULT_ENCODING", resultCharset)
 
-        self.WorkerName = WorkerName                    # 当前进程名称. 如果有参数传递，以参数为准
+        # 当前进程名称. 如果有参数传递，以参数为准.  如果没有，用MAIN加进程ID来标记
+        if workerName == "MAIN":
+            self.workerName = "MAIN-" + str(os.getpid())
+        else:
+            self.workerName = workerName
         self.profile = []                               # 程序的初始化脚本文件
-        self.lastComment = None                       # 如果当前SQL之前的内容完全是注释，则注释带到这里
+        self.lastComment = None                         # 如果当前SQL之前的内容完全是注释，则注释带到这里
 
         # 传递各种参数
-        self.commandScript = script
+        self.commandScript = script                     # 初始化运行的脚本名称，即runCli的脚本名称
+        self.executeScript = script                     # 当前正在执行的脚本名称。 可能会由于start命令而发生切换
         self.commandMap = commandMap
         self.nologo = nologo
         self.logon = logon
         self.logfilename = logfilename
         self.Console = Console
-        self.HeadlessMode = HeadlessMode
+        self.headlessMode = headlessMode
         self.xlogFile = xlog
-        if HeadlessMode:
+        self.xlogOverwrite = xlogoverwrite
+        if headlessMode:
             self.Console = open(os.devnull, "w")
         self.logger = logger
         self.suitename = suitename
@@ -195,7 +200,7 @@ class TestCli(object):
         self.cmdExecuteHandler.cliHandler = self
         self.cmdExecuteHandler.script = script
         self.cmdExecuteHandler.testOptions = self.testOptions
-        self.cmdExecuteHandler.workerName = self.WorkerName
+        self.cmdExecuteHandler.workerName = self.workerName
         self.cmdExecuteHandler.cmdMappingHandler = self.cmdMappingHandler
 
         self.DataHandler.SQLOptions = self.testOptions
@@ -234,17 +239,11 @@ class TestCli(object):
                 m_DriverName = None
                 m_JarFullFileName = []
                 m_JDBCURL = None
-                m_ODBCURL = None
                 m_JDBCProp = None
                 m_jar_filename = None
                 m_DatabaseType = row[0].strip()
                 for m_driversection in str(row[1]).split(','):
                     m_driversection = m_driversection.strip()
-                    if m_ODBCURL is None:
-                        try:
-                            m_ODBCURL = self.AppOptions.get(m_driversection, "odbcurl")
-                        except (configparser.NoSectionError, configparser.NoOptionError):
-                            m_ODBCURL = None
                     if m_DriverName is None:
                         try:
                             m_DriverName = self.AppOptions.get(m_driversection, "driver")
@@ -279,8 +278,7 @@ class TestCli(object):
                              "FullName": m_JarFullFileName,
                              "JDBCURL": m_JDBCURL,
                              "JDBCProp": m_JDBCProp,
-                             "Database": m_DatabaseType,
-                             "ODBCURL": m_ODBCURL}
+                             "Database": m_DatabaseType}
                 self.db_connectionConf.append(jarConfig)
 
         # 设置Meta连接时候需要用到的JarList1
@@ -299,13 +297,20 @@ class TestCli(object):
 
         # 处理传递的映射文件, 首先加载参数的部分，如果环境变量里头有设置，则环境变量部分会叠加参数部分
         self.testOptions.set("TESTREWRITE", "OFF")
-        if self.commandMap is not None:  # 如果传递的参数，有Mapping，以参数为准，先加载参数中的Mapping文件
+        if self.commandMap is not None:
+            # 如果传递的参数，有Mapping，以参数为准，先加载参数中的Mapping文件
             self.cmdMappingHandler.loadCommandMappings(self.commandScript, self.commandMap)
             self.testOptions.set("TESTREWRITE", "ON")
-        if "SQLCLI_COMMANDMAPPING" in os.environ:  # 如果没有参数，则以环境变量中的信息为准
+        if "SQLCLI_COMMANDMAPPING" in os.environ:
+            # 如果没有参数，则以环境变量中的信息为准
             if len(os.environ["SQLCLI_COMMANDMAPPING"].strip()) > 0:
                 self.cmdMappingHandler.loadCommandMappings(self.commandScript, os.environ["SQLCLI_COMMANDMAPPING"])
                 self.testOptions.set("TESTREWRITE", "ON")
+        if "TESTCLI_COMMANDMAPPING" in os.environ:
+            # 如果没有参数，则以环境变量中的信息为准
+            if len(os.environ["TESTCLI_COMMANDMAPPING"].strip()) > 0:
+                self.cmdMappingHandler.loadCommandMappings(self.commandScript, os.environ["TESTCLI_COMMANDMAPPING"])
+                self.testOptions.set("TESTREWRITE", "ON")
 
         # 给Page做准备，PAGE显示的默认换页方式.
         if not os.environ.get("LESS"):
@@ -313,7 +318,10 @@ class TestCli(object):
 
         # 如果参数要求不显示版本，则不再显示版本
         if not self.nologo:
-            self.echo("TestCli Release " + __version__)
+            self.echo(
+                s="TestCli Release " + __version__,
+                Flags=OFLAG_LOGGER | OFLAG_CONSOLE | OFLAG_SPOOL | OFLAG_ECHO,
+            )
 
         # 处理初始化启动文件，如果需要的话，在处理的过程中不打印任何日志信息
         if len(self.profile) != 0:
@@ -519,7 +527,7 @@ class TestCli(object):
                                 if p_result["rawCommand"]["name"] == "SPOOL":
                                     if p_result["rawCommand"]["file"].strip().upper() == "OFF":
                                         m_EchoFlag = m_EchoFlag & ~OFLAG_SPOOL
-                            if p_result["script"] is None:
+                            if p_result["script"] == "Console":
                                 # 控制台应用，不再打印SQL语句到控制台（因为用户已经输入了)
                                 m_EchoFlag = m_EchoFlag & ~OFLAG_CONSOLE
                             if p_result["formattedCommand"] is not None:
@@ -588,16 +596,20 @@ class TestCli(object):
                         nameSpace=self.nameSpace):
                 # 打印结果
                 show_result(result)
+
+                # 记录语句的统计信息
                 if result["type"] == "statistics":
                     if self.testOptions.get('TIMING').upper() == 'ON':
                         self.echo('Running time elapsed: %9.2f seconds' % result["elapsed"])
                     if self.testOptions.get('TIME').upper() == 'ON':
                         self.echo('Current clock time  :' + strftime("%Y-%m-%d %H:%M:%S", localtime()))
+
+                # 如果遇到了错误，且设置了breakWithError，则立刻退出
                 if result["type"] == "error":
-                    # 如果遇到了错误，且要求退出，则立刻退出
                     if self.breakWithError:
                         self.exitValue = self.breakErrorCode
                         raise EOFError
+
             # 返回正确执行的消息
             return True
         except EOFError as e:
@@ -616,66 +628,6 @@ class TestCli(object):
             self.echo(repr(e), err=True, fg="red")
             return False
 
-    # 下载程序所需要的各种Jar包
-    def syncdriver(self):
-        # 加载程序的配置文件
-        self.AppOptions = configparser.ConfigParser()
-        m_conf_filename = os.path.join(os.path.dirname(__file__), "conf", "testcli.ini")
-        if os.path.exists(m_conf_filename):
-            self.AppOptions.read(m_conf_filename)
-
-        # 下载运行需要的各种Jar包
-        for row in self.AppOptions.items("driver"):
-            print("Checking driver [" + row[0] + "] ... ")
-            for m_driversection in str(row[1]).split(','):
-                m_driversection = m_driversection.strip()
-                try:
-                    m_driver_filename = self.AppOptions.get(m_driversection, "filename")
-                    m_driver_downloadurl = self.AppOptions.get(m_driversection, "downloadurl")
-                    m_driver_filemd5 = self.AppOptions.get(m_driversection, "md5")
-
-                    m_LocalJarFile = os.path.join(os.path.dirname(__file__), "jlib", m_driver_filename)
-                    m_LocalJarPath = os.path.join(os.path.dirname(__file__), "jlib")
-                    if not os.path.isdir(m_LocalJarPath):
-                        os.makedirs(m_LocalJarPath)
-
-                    if os.path.exists(m_LocalJarFile):
-                        with open(m_LocalJarFile, 'rb') as fp:
-                            data = fp.read()
-                        file_md5 = hashlib.md5(data).hexdigest()
-                        if "TESTCLI_DEBUG" in os.environ:
-                            print("File=[" + m_driver_filename + "], MD5=[" + file_md5 + "]")
-                    else:
-                        if "TESTCLI_DEBUG" in os.environ:
-                            print("File=[" + m_driver_filename + "] does not exist!")
-                        file_md5 = ""
-                    if file_md5 != m_driver_filemd5.strip():
-                        print("Driver [" + m_driversection + "], need upgrade ...")
-                        # 重新下载新的文件到本地
-                        try:
-                            http = urllib3.PoolManager()
-                            with http.request('GET', m_driver_downloadurl, preload_content=False) as r, \
-                                    open(m_LocalJarFile, 'wb') as out_file:
-                                shutil.copyfileobj(r, out_file)
-                        except URLError:
-                            print('traceback.print_exc():\n%s' % traceback.print_exc())
-                            print('traceback.format_exc():\n%s' % traceback.format_exc())
-                            print("")
-                            print("Driver [" + m_driversection + "] download failed.")
-                            continue
-                        with open(m_LocalJarFile, 'rb') as fp:
-                            data = fp.read()
-                        file_md5 = hashlib.md5(data).hexdigest()
-                        if file_md5 != m_driver_filemd5.strip():
-                            print("Driver [" + m_driversection + "] consistent check failed. "
-                                                                 "Remote MD5=[" + str(file_md5) + "]")
-                        else:
-                            print("Driver [" + m_driversection + "] is up-to-date.")
-                    else:
-                        print("Driver [" + m_driversection + "] is up-to-date.")
-                except (configparser.NoSectionError, configparser.NoOptionError):
-                    print("Bad driver config [" + m_driversection + "], Skip it ...")
-
     # 主程序
     def run_cli(self):
         # 如果运行在脚本方式下，不再调用PromptSession
@@ -709,6 +661,11 @@ class TestCli(object):
                 os.environ.pop(s)
 
         try:
+            # 如果用户指定了用户名，口令，尝试直接进行数据库连接
+            if self.logon:
+                if not self.DoCommand("_connect " + str(self.logon)):
+                    raise EOFError
+
             # 开始依次处理控制台送来的语句
             if not self.commandScript:
                 while True:
@@ -716,11 +673,6 @@ class TestCli(object):
                     if not self.DoCommand():
                         raise EOFError
 
-            # 如果用户指定了用户名，口令，尝试直接进行数据库连接
-            if self.logon:
-                if not self.DoCommand("_connect " + str(self.logon)):
-                    raise EOFError
-
             # 如果传递的参数中有脚本文件，先执行脚本文件, 执行完成后自动退出
             try:
                 # 如果有脚本目录，则运行的时候切换到脚本所在的目录下，运行结束后要返回当前目录
@@ -731,13 +683,13 @@ class TestCli(object):
                     # 如果脚本不是当前目录，需要切换到脚本目录下
                     # 如果脚本是当前目录，切换到空目录会报错，所以不能切换
                     os.chdir(scriptDir)
-                self.DoCommand('_start ' + scriptBase)
+                self.DoCommand(text='_start ' + scriptBase)
                 if scriptDir.strip() != "":
                     # 如果发生了脚本切换，则执行脚本后要返回切换前的目录
                     os.chdir(currentPwd)
             except TestCliException:
                 raise EOFError
-            self.DoCommand('_exit')
+            self.DoCommand(text='_exit')
         except (TestCliException, EOFError):
             pass
 
@@ -850,15 +802,15 @@ class TestCli(object):
 
     def format_output_csv(self, headers, columnTypes, cur):
         # 将屏幕输出按照CSV格式进行输出
-        m_csv_delimiter = self.testOptions.get("CSV_DELIMITER")
-        m_csv_quotechar = self.testOptions.get("CSV_QUOTECHAR")
+        m_csv_delimiter = self.testOptions.get("OUTPUT_CSV_DELIMITER")
+        m_csv_quotechar = self.testOptions.get("OUTPUT_CSV_QUOTECHAR")
         if m_csv_delimiter.find("\\t") != -1:
             m_csv_delimiter = m_csv_delimiter.replace("\\t", '\t')
         if m_csv_delimiter.find("\\s") != -1:
             m_csv_delimiter = m_csv_delimiter.replace("\\s", ' ')
 
         # 打印字段名称
-        if self.testOptions.get("CSV_HEADER") == "ON":
+        if self.testOptions.get("OUTPUT_CSV_HEADER") == "ON":
             m_row = ""
             for pos in range(0, len(headers)):
                 m_row = m_row + str(headers[pos])
@@ -1129,25 +1081,29 @@ class TestCli(object):
         try:
             self.xlogFileLocker.acquire()
             if self.xlogFileHandle is None:
-                # 如果文件已经存在，则删除当前文件
-                if os.path.exists(self.xlogFile):
-                    os.remove(self.xlogFile)
                 # 创建文件，并写入文件头信息
+                if self.xlogOverwrite:
+                    # 如果打开了覆盖模式，则删除之前的历史文件
+                    if os.path.exists(self.xlogFile):
+                        os.remove(self.xlogFile)
                 self.xlogFileHandle = sqlite3.connect(self.xlogFile)
                 cursor = self.xlogFileHandle.cursor()
-                cursor.execute("Create Table TestCli_Xlog "
+                cursor.execute("CREATE TABLE IF NOT EXISTS TestCli_Xlog "
                                "("
+                               "  Id              INTEGER PRIMARY KEY AUTOINCREMENT,"
                                "  Script          TEXT,"
                                "  Started         DATETIME,"
                                "  Elapsed         NUMERIC,"
                                "  RawCommand      TEXT,"
+                               "  CommandType     TEXT,"
                                "  Command         TEXT,"
-                               "  CommandStatus   INTEGER,"
-                               "  ErrorMessage    TEXT,"
+                               "  CommandStatus   TEXT,"
+                               "  ErrorCode       TEXT,"
                                "  WorkerName      TEXT,"
                                "  SuiteName       TEXT,"
                                "  CaseName        TEXT,"
-                               "  Scenario        TEXT"
+                               "  ScenarioId      TEXT,"
+                               "  ScenarioName    TEXT"
                                ")"
                                "")
                 cursor.close()
@@ -1157,32 +1113,31 @@ class TestCli(object):
             threadName = str(commandResult["thread_name"])
 
             # 写入内容信息
-            if self.commandScript is None:
+            if self.executeScript is None:
                 script = "Console"
             else:
-                script = str(os.path.basename(self.commandScript))
-
-            # 打开xLog文件
-            if self.xlogFileHandle is not None:
-                self.xlogFileHandle = sqlite3.connect(self.xlogFile)
+                script = str(os.path.basename(self.executeScript))
             cursor = self.xlogFileHandle.cursor()
             data = (
                 script,
                 time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(commandResult["startedTime"])),
                 "%8.2f" % commandResult["elapsed"],
                 str(commandResult["rawCommand"]),
+                str(commandResult["commandType"]),
                 str(commandResult["command"]),
                 str(commandResult["commandStatus"]),
-                str(commandResult["errorMessage"]),
+                str(commandResult["errorCode"]),
                 str(threadName),
                 str(self.suitename),
                 str(self.casename),
-                str(commandResult["scenario"])
+                str(commandResult["scenarioId"]),
+                str(commandResult["scenarioName"])
             )
             cursor.execute(
                 "Insert Into TestCli_Xlog(Script,Started,Elapsed,RawCommand,"
-                "Command,CommandStatus,ErrorMessage,WorkerName,SuiteName,CaseName,Scenario) "
-                "Values(?,?,?,?, ?,?,?,?,?,?,?)",
+                "CommandType,Command,CommandStatus,ErrorCode,WorkerName,SuiteName,CaseName,"
+                "ScenarioId, ScenarioName) "
+                "Values(?,?,?,?, ?,?,?,?,?,?,?, ?,?)",
                 data
             )
             cursor.close()
@@ -1190,4 +1145,7 @@ class TestCli(object):
         except Exception as ex:
             print("Internal error:: xlog file [" + str(self.xlogFile) + "] write not complete. " + repr(ex))
         finally:
+            if self.xlogFileHandle:
+                self.xlogFileHandle.close()
+                self.xlogFileHandle = None
             self.xlogFileLocker.release()
